SubscriberInstruction

Enum SubscriberInstruction 

pub enum SubscriberInstruction {
    Subscribe {
        nonce: Nonce,
        handler: Subscription,
    },
    Unsubscribe {
        nonce: Nonce,
    },
    Update {
        nonce: Nonce,
        handler: Subscription,
    },
    Destroy {
        nonce: Nonce,
    },
}
Subscriber program instructions

Variants



Subscribe

Subscribe to events

Fields

nonce: Nonce

Nonce to differentiate handlers for the same topic



Unsubscribe

Delete subscription

Fields

nonce: Nonce

Nonce to differentiate handlers for the same topic/signer pair



Update

Update subscription

Fields

nonce: Nonce

Nonce used during subscription to differentiate handlers for the same topic/signer pair

handler: Subscription

New Subscription data



Destroy

Destroy subscription account.

The instruction transfers funds from the subscription account to the subscriber, marking the subscription account as removable.

This instruction does not emit any logs.

Fields

nonce: Nonce

Nonce to differentiate handlers for the same topic/signer pair

Implementations

Source

impl SubscriberInstruction

pub fn subscribe_to( signer: Pubkey, nonce: Nonce, handler: Subscription, ) -> Instruction

Create a SubscriberInstruction::SubscribeToEvent Instruction

Account references
  1. [SIGNER] Signer (subscriber) account
  2. [WRITE] Subscription data account
  3. [READONLY] System program account
Arguments
  • signer - The public key of the subscriber
  • nonce - The nonce to differentiate handlers for the same topic/signer pair
  • handler - The Subscription data
Returns
  • Instruction - An SVM instruction to be included in a transaction
pub fn unsubscribe_from(signer: Pubkey, nonce: Nonce) -> Instruction

Create a SubscriberInstruction::Unsubscribe Instruction

Account references
  1. [SIGNER] Signer (subscriber) account
  2. [WRITE] Subscription data account
Arguments
  • signer - The public key of the subscriber
  • nonce - The nonce to differentiate handlers for the same topic/signer pair
Returns
  • Instruction - An SVM instruction to be included in a transaction
pub fn update( signer: Pubkey, nonce: Nonce, handler: Subscription, ) -> Instruction

Create a SubscriberInstruction::Update Instruction.

Account references
  1. [SIGNER] Signer (subscriber) account
  2. [WRITE] Subscription data account
  3. [READONLY] System program account
Arguments
  • signer - The public key of the subscriber
  • nonce - The nonce set during subscription to differentiate handlers for the same topic/signer pair
  • handler - The Subscription data
Returns
  • Instruction - An SVM instruction to be included in a transaction