pub struct Predicate { /* private fields */ }Expand description
Represents the predicates set by a subscriber to match the Subscription to an event.
Implementations
Sourceimpl Predicate
impl Predicate
Sourcepub fn new_with_event_account(
topic: impl Into<String>,
event_account: Pubkey,
) -> Self
pub fn new_with_event_account( topic: impl Into<String>, event_account: Pubkey, ) -> Self
Sourcepub fn new_with_optional_event_account(
topic: impl Into<String>,
event_account: Option<Pubkey>,
) -> Self
pub fn new_with_optional_event_account( topic: impl Into<String>, event_account: Option<Pubkey>, ) -> Self
Sourcepub fn new_with_timestamp_range(range: Range<u64>) -> Self
pub fn new_with_timestamp_range(range: Range<u64>) -> Self
Create a new predicate for a timestamp range.
The topic is set to the clock topic and the event account is set to the clock sysvar account.
Arguments
range- A range representing the timestamp range in milliseconds. The start is inclusive, and the end is exclusive.
Returns
Predicate- A new instance ofPredicate
Sourcepub fn event_account(&self) -> Option<Pubkey>
pub fn event_account(&self) -> Option<Pubkey>
Get the event account of the predicate, if any.
Sourcepub fn timestamp_range(&self) -> Option<TimestampRange>
pub fn timestamp_range(&self) -> Option<TimestampRange>
Get the timestamp range of the predicate, if any.