pub struct Subscription {
pub subscriber: Pubkey,
pub predicate: Predicate,
pub instructions: Vec<Instruction>,
pub kind: SubscriptionKind,
pub active_commits: RangeInclusive<Commmit>,
}Expand description
Subscription data stored by a user for a given topic. This is used to generate scheduled
transactions to be run if the topic is triggered.
The instructions are a set of SVM instructions that are meant to be run when the subscription is
triggered. The instruction array is converted to a SanitizedTransaction and executed in the VM.
Fields
subscriber: PubkeySubscriber key
predicate: PredicateThe predicate set by the subscriber to match the event
instructions: Vec<Instruction>Instructions to be executed
kind: SubscriptionKindSubscription kind
active_commits: RangeInclusive<Commmit>Active commits for the subscription
Implementations
Sourceimpl Subscription
impl Subscription
Sourcepub fn new(
subscriber: Pubkey,
predicate: Predicate,
instructions: Vec<Instruction>,
kind: SubscriptionKind,
active_commits: RangeInclusive<u64>,
) -> Self
pub fn new( subscriber: Pubkey, predicate: Predicate, instructions: Vec<Instruction>, kind: SubscriptionKind, active_commits: RangeInclusive<u64>, ) -> Self
Instantiate a new Subscription
Arguments
subscriber- The public key of the subscriberpredicate- The predicate to match the eventinstructions- A vector of instructions to be executedkind- The type of subscription (persistent or one-shot)active_commits- The range of active commits for the subscription
Returns
Subscription- A new instance ofSubscription
Sourcepub fn sanitize_instructions(&self) -> Result<(), SubscriptionError>
pub fn sanitize_instructions(&self) -> Result<(), SubscriptionError>
Sanitize a Subscription
Returns
Result<(), SubscriptionError> - Ok if the subscription is valid, Err otherwise