pub type Commmit = u64;Expand description
Type representing a commit index on Rialo. In Rialo there are currently 3 representations of a block height:
- Round: A round is a representation of a block height in the consensus layer. Each round
contains a fixed number of blocks. A round is identified by a
u32index. - Commit index: A commit index is a representation of a block height in the execution layer.
Each commit index corresponds to a DAG that is an output from consensus. A commit index is identified
by a
u32index. - Slot: A slot is a representation of a block height in the Solana layer. Each slot corresponds to a block in
the Solana layer. A slot is identified by a
u32index.
On Rialo we use commit indexes to represent block heights in the execution layer. This makes the value
for a Commit Index and a Slot the same, but they represent different concepts. The Commit type
used here is leverage at execution time around the Virtual Machine, thus it follows the u64 type
used in Solana for slots.