pub enum SubscriberInstruction {
Subscribe {
nonce: Nonce,
handler: Subscription,
},
Unsubscribe {
nonce: Nonce,
},
Update {
nonce: Nonce,
handler: Subscription,
},
Destroy {
nonce: Nonce,
},
}Expand description
Subscriber program instructions
Variants
Subscribe
Subscribe to events
Fields

handler: SubscriptionSubscription data
Unsubscribe
Delete subscription
Update
Update subscription
Fields

nonce: NonceNonce used during subscription to differentiate handlers for the same topic/signer pair

handler: SubscriptionNew Subscription data
Destroy
Destroy subscription account.
The instruction transfers funds from the subscription account to the subscriber, marking the subscription account as removable.
This instruction does not emit any logs.
Implementations
Sourceimpl SubscriberInstruction
impl SubscriberInstruction
Sourcepub fn subscribe_to(
signer: Pubkey,
nonce: Nonce,
handler: Subscription,
) -> Instruction
pub fn subscribe_to( signer: Pubkey, nonce: Nonce, handler: Subscription, ) -> Instruction
Create a SubscriberInstruction::SubscribeToEvent Instruction
Account references
[SIGNER]Signer (subscriber) account[WRITE]Subscription data account[READONLY]System program account
Arguments
signer- The public key of the subscribernonce- The nonce to differentiate handlers for the same topic/signer pairhandler- TheSubscriptiondata
Returns
Instruction- An SVM instruction to be included in a transaction
Sourcepub fn unsubscribe_from(signer: Pubkey, nonce: Nonce) -> Instruction
pub fn unsubscribe_from(signer: Pubkey, nonce: Nonce) -> Instruction
Create a SubscriberInstruction::Unsubscribe Instruction
Account references
[SIGNER]Signer (subscriber) account[WRITE]Subscription data account
Arguments
signer- The public key of the subscribernonce- The nonce to differentiate handlers for the same topic/signer pair
Returns
Instruction- An SVM instruction to be included in a transaction
Sourcepub fn update(
signer: Pubkey,
nonce: Nonce,
handler: Subscription,
) -> Instruction
pub fn update( signer: Pubkey, nonce: Nonce, handler: Subscription, ) -> Instruction
Create a SubscriberInstruction::Update Instruction.
Account references
[SIGNER]Signer (subscriber) account[WRITE]Subscription data account[READONLY]System program account
Arguments
signer- The public key of the subscribernonce- The nonce set during subscription to differentiate handlers for the same topic/signer pairhandler- TheSubscriptiondata
Returns
Instruction- An SVM instruction to be included in a transaction